Slot: key - LinkML Model

# Slot: key

True means that the key slot(s) uniquely identify the container.

URI: linkml:key

## Domain and Range

SlotDefinition → 0..1 Boolean

## Parents

## Children

## Used by

- SlotDefinition

## Other properties

Comments: |  | see also 'unique_key'
|  | key is inherited
|  | a given domain can have at most one key slot (restriction to be removed in the future)
|  | identifiers and keys are mutually exclusive. A given domain cannot have both
|  | a key slot is automatically required. Keys cannot be optional